summaryrefslogtreecommitdiffstats
path: root/kttsd/libkttsd/filterconf.h
diff options
context:
space:
mode:
Diffstat (limited to 'kttsd/libkttsd/filterconf.h')
-rw-r--r--kttsd/libkttsd/filterconf.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kttsd/libkttsd/filterconf.h b/kttsd/libkttsd/filterconf.h
index 9b52c31..606813c 100644
--- a/kttsd/libkttsd/filterconf.h
+++ b/kttsd/libkttsd/filterconf.h
@@ -58,7 +58,7 @@ class KDE_EXPORT KttsFilterConf : public TQWidget{
* loaded, so it not necessary to call it in your constructor.
* The plugin should read its configuration from the specified group
* in the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
*
@@ -67,7 +67,7 @@ class KDE_EXPORT KttsFilterConf : public TQWidget{
* any instance-specific parameters to load, but it may still wish
* to load parameters that apply to all instances of the plugin.
*/
- virtual void load(KConfig *config, const TQString &configGroup);
+ virtual void load(TDEConfig *config, const TQString &configGroup);
/**
* This function gets called when the user wants to save the settings in
@@ -75,11 +75,11 @@ class KDE_EXPORT KttsFilterConf : public TQWidget{
* configuration is stored. The method is called when the user clicks "Apply"
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.
*/
- virtual void save(KConfig *config, const TQString &configGroup);
+ virtual void save(TDEConfig *config, const TQString &configGroup);
/**
* This function is called to set the settings in the module to sensible
@@ -58,7 +58,7 @@ class KDE_EXPORT KttsFilterConf : public TQWidget{
* The plugin should read its configuration from the specified group
* in the specified config file.
- * @param config Pointer to a KConfig object.
+ * @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
@@ -75,11 +75,11 @@ class KDE_EXPORT KttsFilterConf : public TQWidget{
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
- * @param config Pointer to a KConfig object.
+ * @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.